Db2Mag

Trait Db2Mag 

pub trait Db2Mag {
    // Required method
    fn db2mag(&self) -> Self;
}
A trait for types that can convert from decibels to magnitude.

This trait provides a method to convert a value from decibels to magnitude.

Methods

  • db2mag(&self): Converts the decibel value to magnitude.

Required Methods

fn db2mag(&self) -> Self

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Db2Mag for f32

Source

fn db2mag(&self) -> Self

Source

impl Db2Mag for f64

Source

fn db2mag(&self) -> Self

Implementors