pub trait Db2Mag {
// Required method
fn db2mag(&self) -> Self;
}Expand description
A trait for types that can convert from decibels to magnitude.
This trait provides a method to convert a value from decibels to magnitude.
Methods
db2mag(&self): Converts the decibel value to magnitude.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".